@@ -1,7 +1,7 @@
 #!/bin/sh
 #
 #       tardy - a tar post-processor
-#       Copyright (C) 1993-1995, 1998-2000, 2008 Peter Miller
+#       Copyright (C) 1993-1995, 1998-2000, 2008, 2011 Peter Miller
 #
 #       This program is free software; you can redistribute it and/or modify
 #       it under the terms of the GNU General Public License as published by
@@ -96,7 +96,7 @@ ${TAB}rm -f bin/tardy
 
 distclean: clean
 ${TAB}rm -f config.status config.cache config.log
-${TAB}rm -f Makefile common/config.h etc/Howto.conf
+${TAB}rm -f Makefile common/config.h etc/howto.conf
 
 .bin:
 ${TAB}-mkdir bin
