@@ -92,13 +92,14 @@ memmem(const void *haystack_v, size_t haystack_size, const void *needle_v,
     }
     const unsigned char *needle = (const unsigned char *)needle_v;
     if (needle_size == 1)
-        return memchr(haystack_v, needle[0], haystack_size);
+        return (void *)memchr(haystack_v, needle[0], haystack_size);
     const unsigned char *haystack = (const unsigned char *)haystack_v;
     const unsigned char *haystack_end =
         haystack + haystack_size - needle_size + 1;
     while (haystack < haystack_end)
     {
         const unsigned char *first =
+            (const unsigned char *)
             memchr(haystack, needle[0], haystack_end - haystack);
         if (!first)
             break;
@@ -109,4 +110,4 @@ memmem(const void *haystack_v, size_t haystack_size, const void *needle_v,
     return 0;
 }
 
-#endif
+#endif // HAVE_MEMMEM
