@@ -1,6 +1,6 @@
 //
 // tardy - a tar post-processor
-// Copyright (C) 1998, 1999, 2001, 2002, 2004, 2008, 2009, 2011 Peter Miller
+// Copyright (C) 1998-2002, 2004, 2008, 2009, 2011, 2012 Peter Miller
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -69,7 +69,7 @@ file_input::valid(void)
 }
 
 
-int
+size_t
 file_input::read(void *data, size_t data_size)
 {
     assert(valid());
@@ -121,7 +121,7 @@ file_input::unread(const void *data, size_t data_size)
 }
 
 
-int
+size_t
 file_input::peek(void *data, size_t data_size)
 {
     int nbytes = read(data, data_size);
@@ -131,9 +131,9 @@ file_input::peek(void *data, size_t data_size)
 
 
 void
-file_input::skip(size_t nbytes)
+file_input::skip(off_t nbytes)
 {
-    size_t tot = 0;
+    off_t tot = 0;
     while (nbytes > 0)
     {
         char dummy[512];
@@ -143,12 +143,24 @@ file_input::skip(size_t nbytes)
         size_t n2 = read(dummy, n);
         if (n != n2)
         {
-            fatal
-            (
-                "short padding read (requested %ld, got %ld)",
-                tot + n,
-                tot + n2
-            );
+            if (sizeof(off_t) > sizeof(long))
+            {
+                fatal
+                (
+                    "short padding read (requested %llu, got %llu)",
+                    (unsigned long long)(tot + n),
+                    (unsigned long long)(tot + n2)
+                );
+            }
+            else
+            {
+                fatal
+                (
+                    "short padding read (requested %lu, got %lu)",
+                    (unsigned long)(tot + n),
+                    (unsigned long)(tot + n2)
+                );
+            }
         }
         nbytes -= n;
         tot += n;
@@ -156,12 +168,15 @@ file_input::skip(size_t nbytes)
 }
 
 
-unsigned long
+off_t
 file_input::get_position(void)
     const
 {
-    unsigned read_ahead_available = read_ahead_size - read_ahead_pos;
-    unsigned long pos = get_position_inner();
-    assert(pos >= read_ahead_available);
+    size_t read_ahead_available = read_ahead_size - read_ahead_pos;
+    off_t pos = get_position_inner();
+    assert(pos >= (off_t)read_ahead_available);
     return (pos - read_ahead_available);
 }
+
+
+// vim: set ts=8 sw=4 et :
