@@ -1,6 +1,6 @@
 //
 // tardy - a tar post-processor
-// Copyright (C) 1998, 1999, 2004, 2008, 2009, 2011 Peter Miller
+// Copyright (C) 1998, 1999, 2004, 2008, 2009, 2011-2013 Peter Miller
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -19,7 +19,7 @@
 #ifndef LIBTARDY_FILE_INPUT_H
 #define LIBTARDY_FILE_INPUT_H
 
-#include <libtardy/config.h>
+#include <libtardy/ac/sys/types.h>
 #include <boost/shared_ptr.hpp>
 
 #include <libtardy/rcstring.h>
@@ -73,7 +73,7 @@ public:
       * @returns
       *     The number of bytes read into the buffer, or 0 for end of file.
       */
-    int read(void *data, size_t data_size);
+    size_t read(void *data, size_t data_size);
 
     /**
       * The peek method is used to read data from the file, without
@@ -84,8 +84,10 @@ public:
       *     The location to write the data read from the file.
       * @param data_size
       *     The number of bytes read into the buffer from the file.
+      * @returns
+      *     The number of bytes read (and returned)
       */
-    int peek(void *data, size_t data_size);
+    size_t peek(void *data, size_t data_size);
 
     /**
       * The filename method is used to determine the name of the file.
@@ -114,16 +116,16 @@ public:
       *
       * @param nbytes
       *     The number of bytes of input data to discard.  It will be an error
-      *     if the input does nlt contain at least this many bytes.
+      *     if the input does not contain at least this many bytes.
       */
-    void skip(size_t nbytes);
+    void skip(off_t nbytes);
 
     /**
       * The get_position method may be used to obtain the current file
       * position, in bytes from the start of the file.  Any "unread"
       * bytes will be taken into account.
       */
-    unsigned long get_position(void) const;
+    off_t get_position(void) const;
 
 protected:
     /**
@@ -134,15 +136,27 @@ protected:
 
     /**
       * The read_inner method is supplied by derived classes, to
-      * implement that actual machinery of reading data.
+      * implement the actual machinery of reading data.
+      *
+      * @param data
+      *     where to place sthe data read in.
+      * @param data_size
+      *     the maximum number of bytes to read in.
+      * @returns
+      *     The number of bytes read.  Does not return if there is an
+      *     error (which is why return value is unsigned);
       */
-    virtual int read_inner(void *data, size_t data_size) = 0;
+    virtual size_t read_inner(void *data, size_t data_size) = 0;
 
     /**
       * The get_position_inner method may be used to obtain the current
       * file position, in bytes from the start of the file.
+      *
+      * @returns
+      *     the current file read position.  It may exceed 2GB which is
+      *     why we must use off_t (for example, tarballs of .avi files).
       */
-    virtual unsigned long get_position_inner(void) const = 0;
+    virtual off_t get_position_inner(void) const = 0;
 
 private:
     /**
@@ -164,6 +178,9 @@ private:
       * much of the read-ahead buffer has been used.  The used data lies
       * between read_ahead_pos and read_ahead_size; that is, the array
       * is used from back to front.
+      *
+      * (Position within memory buff, so size_t; it is NOT a file
+      * positon, which is why it isn't off_t).
       */
     size_t read_ahead_pos;
 
@@ -198,4 +215,5 @@ private:
     file_input &operator=(const file_input &rhs);
 };
 
+// vim: set ts=8 sw=4 et :
 #endif // LIBTARDY_FILE_INPUT_H
