@@ -1,6 +1,6 @@
 //
 // tardy - a tar post-processor
-// Copyright (C) 2011 Peter Miller
+// Copyright (C) 2011, 2012 Peter Miller
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -16,9 +16,11 @@
 // along with this program. If not, see <http://www.gnu.org/licenses/>.
 //
 
+#include <libtardy/file/input/bunzip2.h>
 #include <libtardy/file/input/gunzip.h>
 #include <libtardy/file/input/normal.h>
 #include <libtardy/file/input/stdin.h>
+#include <libtardy/file/input/xz.h>
 
 
 static bool
@@ -38,8 +40,7 @@ looks_like_stdin(const char *filename)
 file_input::pointer
 file_input::factory(const char *filename)
 {
-    return
-        file_input_gunzip::open
+    file_input::pointer ip =
         (
             looks_like_stdin(filename)
         ?
@@ -47,4 +48,11 @@ file_input::factory(const char *filename)
         :
             file_input_normal::create(filename)
         );
+    ip = file_input_gunzip::create_if_candidate(ip);
+    ip = file_input_bunzip2::create_if_candidate(ip);
+    ip = file_input_xz::create_if_candidate(ip);
+    return ip;
 }
+
+
+// vim: set ts=8 sw=4 et :
