@@ -1,6 +1,6 @@
 //
 // tardy - a tar post-processor
-// Copyright (C) 1998, 1999, 2002, 2008, 2009, 2011 Peter Miller
+// Copyright (C) 1998, 1999, 2002, 2008, 2009, 2011, 2012 Peter Miller
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -66,7 +66,7 @@ file_input_normal::needs_position_filter(void)
 }
 
 
-int
+size_t
 file_input_normal::read_inner(void *data, size_t data_size)
 {
     return explain_read_or_die(fd, data, data_size);
@@ -81,7 +81,7 @@ file_input_normal::filename(void)
 }
 
 
-unsigned long
+off_t
 file_input_normal::get_position_inner(void)
     const
 {
@@ -89,3 +89,6 @@ file_input_normal::get_position_inner(void)
     // an EINVAL error for this system call.
     return explain_lseek_or_die(fd, 0, SEEK_CUR);
 }
+
+
+// vim: set ts=8 sw=4 et :
