@@ -1,6 +1,6 @@
 //
 // tardy - a tar post-processor
-// Copyright (C) 1998, 1999, 2004, 2008, 2009, 2011 Peter Miller
+// Copyright (C) 1998, 1999, 2004, 2008, 2009, 2011, 2012 Peter Miller
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -42,13 +42,13 @@ public:
 
 protected:
     // See base class for documentation.
-    virtual int read_inner(void *data, size_t data_size);
+    virtual size_t read_inner(void *data, size_t data_size);
 
     // See base class for documentation.
     rcstring filename(void) const;
 
     // See base class for documentation.
-    unsigned long get_position_inner(void) const;
+    off_t get_position_inner(void) const;
 
 private:
     /**
@@ -81,4 +81,5 @@ private:
     file_input_stdin &operator=(const file_input_stdin &rhs);
 };
 
+// vim: set ts=8 sw=4 et :
 #endif // LIBTARDY_FILE_INPUT_STDIN_H
