@@ -1,6 +1,6 @@
 //
 // tardy - a tar post-processor
-// Copyright (C) 1998, 1999, 2001-2003, 2008, 2009, 2011 Peter Miller
+// Copyright (C) 1998, 1999, 2001-2003, 2008, 2009, 2011, 2012 Peter Miller
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -64,10 +64,4 @@ file_output::fatal(const char *fmt, ...)
 }
 
 
-bool
-file_output::filename_implies_gzip(void)
-    const
-{
-    rcstring fn = filename().basename().downcase();
-    return (fn.ends_with(".gz") || fn.ends_with(".tgz"));
-}
+// vim: set ts=8 sw=4 et :
