@@ -1,6 +1,6 @@
 //
 // tardy - a tar post-processor
-// Copyright (C) 1998, 1999, 2003, 2004, 2008, 2009, 2011 Peter Miller
+// Copyright (C) 1998, 1999, 2003, 2004, 2008, 2009, 2011, 2012 Peter Miller
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -77,14 +77,7 @@ public:
       * @param data_size
       *     This argument indicates the number fo bytes to be written.
       */
-    virtual void write(const void *data, int data_size) = 0;
-
-    /**
-      * The filename_implies_gzip method may be used to determine
-      * whether or not gzip compression should be used, based on the
-      * file extension of the output file name.
-      */
-    bool filename_implies_gzip(void) const;
+    virtual void write(const void *data, size_t data_size) = 0;
 
 protected:
     /**
@@ -111,4 +104,5 @@ protected:
     file_output &operator=(const file_output &rhs);
 };
 
+// vim: set ts=8 sw=4 et :
 #endif // LIBTARDY_FILE_OUTPUT_H
