@@ -1,6 +1,6 @@
 //
 //      tardy - a tar post-processor
-//      Copyright (C) 2003, 2008, 2009, 2011 Peter Miller
+//      Copyright (C) 2003, 2008, 2009, 2011, 2012 Peter Miller
 //
 //      This program is free software; you can redistribute it and/or modify
 //      it under the terms of the GNU General Public License as published by
@@ -50,7 +50,7 @@ file_output_buffer::file_output_buffer(
 
 file_output::pointer
 file_output_buffer::create(const file_output::pointer &a_deeper,
-    int a_blocksize)
+    size_t a_blocksize)
 {
     return pointer(new file_output_buffer(a_deeper, a_blocksize));
 }
@@ -65,7 +65,7 @@ file_output_buffer::filename(void)
 
 
 void
-file_output_buffer::write(const void *data, int data_size)
+file_output_buffer::write(const void *data, size_t data_size)
 {
     while (data_size > 0)
     {
@@ -84,7 +84,8 @@ file_output_buffer::write(const void *data, int data_size)
         //
         // Add the data to the end of the buffer.
         //
-        int len = blocksize - pos;
+        assert(blocksize >= pos);
+        size_t len = blocksize - pos;
         if (len > data_size)
             len = data_size;
         if (!buffer)
@@ -104,3 +105,6 @@ file_output_buffer::write(const void *data, int data_size)
         data_size -= len;
     }
 }
+
+
+// vim: set ts=8 sw=4 et :
