@@ -1,6 +1,6 @@
 //
 // tardy - a tar post-processor
-// Copyright (C) 2003, 2004, 2008, 2009, 2011 Peter Miller
+// Copyright (C) 2003, 2004, 2008, 2009, 2011, 2012 Peter Miller
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -44,17 +44,17 @@ public:
       *     the data to once it has been buffered.
       * @param blocksize
       *     This argument my be used to specify the block size, in bytes.
-      *     It defaults to 512 bytes if zero or negative.
+      *     It defaults to 512 bytes if zero.
       */
     static pointer create(const file_output::pointer &deeper,
-        int blocksize = 0);
+        size_t blocksize = 0);
 
 protected:
     // See base class for documentation.
     rcstring filename(void) const;
 
     // See base class for documentation.
-    void write(const void *data, int nbytes);
+    void write(const void *data, size_t data_size);
 
 private:
     /**
@@ -79,7 +79,7 @@ private:
       * The blocksize instance variable is used to remember the size of
       * blocks to be wrutten to the deeper output.
       */
-    int blocksize;
+    size_t blocksize;
 
     /**
       * The buffer instance variable is used to remember whe the buffer
@@ -93,7 +93,7 @@ private:
       *
       * Invariant: assert(pos >= 0 && pos < blocksize);
       */
-    int pos;
+    size_t pos;
 
     /**
       * The default constructor.  Do not use.
@@ -117,4 +117,5 @@ private:
     file_output_buffer &operator=(const file_output_buffer &rhs);
 };
 
+// vim: set ts=8 sw=4 et :
 #endif // LIBTARDY_FILE_OUTPUT_BUFFER_H
