@@ -1,6 +1,6 @@
 //
 // tardy - a tar post-processor
-// Copyright (C) 1998, 1999, 2003, 2008, 2009, 2011 Peter Miller
+// Copyright (C) 1998, 1999, 2003, 2008, 2009, 2011, 2012 Peter Miller
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -16,6 +16,7 @@
 // along with this program. If not, see <http://www.gnu.org/licenses/>.
 //
 
+#include <libtardy/ac/assert.h>
 #include <libtardy/ac/fcntl.h>
 #include <libtardy/ac/unistd.h>
 #include <libexplain/close.h>
@@ -48,11 +49,20 @@ file_output_normal::create(const char *a_fn)
 
 
 void
-file_output_normal::write(const void *buffer, int nbytes)
+file_output_normal::write(const void *buffer, size_t nbytes)
 {
-    int count = explain_write_or_die(fd, buffer, nbytes);
-    if (count != nbytes)
-        fatal("short write (gave %d, got %d)", nbytes, count);
+    ssize_t count = explain_write_or_die(fd, buffer, nbytes);
+    assert(count >= 0);
+    // it would be nice to use %zu but backwards compatibility prevents
+    if ((size_t)count != nbytes)
+    {
+        fatal
+        (
+            "short write (gave %lu, got %lu)",
+            (unsigned long)nbytes,
+            (unsigned long)count
+        );
+    }
 }
 
 rcstring
@@ -61,3 +71,6 @@ file_output_normal::filename(void)
 {
     return fn;
 }
+
+
+// vim: set ts=8 sw=4 et :
