@@ -1,6 +1,6 @@
 //
 //      tardy - a tar post-processor
-//      Copyright (C) 1998, 1999, 2003, 2008, 2009, 2011 Peter Miller
+//      Copyright (C) 1998, 1999, 2003, 2008, 2009, 2011, 2012 Peter Miller
 //
 //      This program is free software; you can redistribute it and/or modify
 //      it under the terms of the GNU General Public License as published by
@@ -43,12 +43,20 @@ file_output_stdout::create(void)
 
 
 void
-file_output_stdout::write(const void *data, int data_size)
+file_output_stdout::write(const void *data, size_t data_size)
 {
     int fd = 1;
-    int count = explain_write_or_die(fd, data, data_size);
-    if (count != data_size)
-        fatal("short write (gave %d, got %d)", data_size, count);
+    ssize_t count = explain_write_or_die(fd, data, data_size);
+    assert(count >= 0);
+    if ((size_t)count != data_size)
+    {
+        fatal
+        (
+            "short write (gave %lu, got %lu)",
+            (unsigned long)data_size,
+            (unsigned long)count
+        );
+    }
 }
 
 
@@ -58,3 +66,6 @@ file_output_stdout::filename(void)
 {
     return "standard output";
 }
+
+
+// vim: set ts=8 sw=4 et :
