@@ -1,6 +1,6 @@
 //
 // tardy - a tar post-processor
-// Copyright (C) 1998, 1999, 2003, 2004, 2008, 2009, 2011 Peter Miller
+// Copyright (C) 1998, 1999, 2003, 2004, 2008, 2009, 2011, 2012 Peter Miller
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -42,7 +42,7 @@ public:
 
 protected:
     // See base class for documentation.
-    virtual void write(const void *data, int data_size);
+    virtual void write(const void *data, size_t data_size);
 
     // See base class for documentation.
     rcstring filename(void) const;
@@ -71,4 +71,5 @@ private:
     file_output_stdout &operator=(const file_output_stdout &rhs);
 };
 
+// vim: set ts=8 sw=4 et :
 #endif // LIBTARDY_FILE_OUTPUT_STDOUT_H
