@@ -1,6 +1,6 @@
 //
 // tardy - a tar post-processor
-// Copyright (C) 2002, 2008, 2009, 2011 Peter Miller
+// Copyright (C) 2002, 2008, 2009, 2011, 2012 Peter Miller
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -18,6 +18,7 @@
 
 #include <libtardy/ac/string.h>
 #include <libtardy/filenamelist/file.h>
+#include <libtardy/rcstring/accumulator.h>
 
 
 filenamelist_file::~filenamelist_file()
@@ -57,39 +58,31 @@ filenamelist_file::read_one_char(void)
 bool
 filenamelist_file::read_one_line(rcstring &result)
 {
-    static char *temp;
-    static size_t maximum;
-    size_t line_length = 0;
+    static rcstring_accumulator acc;
+    acc.clear();
     for (;;)
     {
-        int c = read_one_char();
-        if (c < 0)
+        int ic = read_one_char();
+        if (ic < 0)
         {
-            if (line_length)
+            if (!acc.empty())
             {
-                while (line_length && temp[line_length - 1] == '/')
-                    --line_length;
-                result = rcstring(temp, line_length);
+                while (acc.back() == '/')
+                    acc.pop_back();
+                result = acc.mkstr();
                 return true;
             }
             return false;
         }
+        unsigned char c = ic;
         if (c == '\n')
         {
-            while (line_length && temp[line_length - 1] == '/')
-                --line_length;
-            result = rcstring(temp, line_length);
+            while (acc.back() == '/')
+                acc.pop_back();
+            result = acc.mkstr();
             return true;
         }
-        if (line_length >= maximum)
-        {
-            maximum = maximum * 2 + 16;
-            char *temp2 = new char[maximum];
-            memcpy(temp2, temp, line_length);
-            delete temp;
-            temp = temp2;
-        }
-        temp[line_length++] = c;
+        acc.push_back((unsigned char)c);
     }
 }
 
@@ -100,3 +93,6 @@ filenamelist_file::filename(void)
 {
     return source->filename();
 }
+
+
+// vim: set ts=8 sw=4 et :
