@@ -1,6 +1,6 @@
 //
 // tardy - a tar post-processor
-// Copyright (C) 2002, 2008, 2009, 2011 Peter Miller
+// Copyright (C) 2002, 2008, 2009, 2011, 2012 Peter Miller
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -72,13 +72,13 @@ private:
       * The position instance variable is used to remember the
       * current position within the #buffer.
       */
-    int position;
+    size_t position;
 
     /**
       * The length instance variable is used to remember the number
       * of valid characters within the #buffer.
       */
-    int length;
+    size_t length;
 
     /**
       * The buffer instance variable is used to remember data read
@@ -109,4 +109,5 @@ private:
     filenamelist_file &operator=(const filenamelist_file &);
 };
 
+// vim: set ts=8 sw=4 et :
 #endif // LIBTARDY_FILENAMELIST_FILE_H
