@@ -1,6 +1,6 @@
 //
 // tardy - a tar post-processor
-// Copyright (C) 2002, 2008, 2009, 2011 Peter Miller
+// Copyright (C) 2002, 2008, 2009, 2011, 2012 Peter Miller
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -54,47 +54,64 @@ filenamelist_filter_progress::create(const filenamelist::pointer &a_deeper)
 }
 
 
+static void
+format_size_inner(char *buffer, size_t sizeof_buffer, double d, char scale)
+{
+    if (d < 10)
+    {
+        snprintf(buffer, sizeof_buffer, "%4.2f%c", d, scale);
+        return;
+    }
+    if (d < 100)
+    {
+        snprintf(buffer, sizeof_buffer, "%4.1f%c", d, scale);
+        return;
+    }
+    snprintf(buffer, sizeof(buffer), "%4.0f%c", d, scale);
+}
+
+
 static char *
-format_size(long long x)
+format_size(long long n)
 {
     static char buffer[10];
-    if (x < 10000)
+    if (n < 10000)
     {
-        snprintf(buffer, sizeof(buffer), "%4d ", (int)x);
+        snprintf(buffer, sizeof(buffer), "%4d ", (int)n);
         return buffer;
     }
-    x >>= 10;
-    if (x < 10000)
+    double d = n / 1024.;
+    if (d < 10000)
     {
-        snprintf(buffer, sizeof(buffer), "%4dK", (int)x);
+        format_size_inner(buffer, sizeof(buffer), d, 'K');
         return buffer;
     }
-    x >>= 10;
-    if (x < 10000)
+    d /= 1024;
+    if (d < 10000)
     {
-        snprintf(buffer, sizeof(buffer), "%4dM", (int)x);
+        format_size_inner(buffer, sizeof(buffer), d, 'M');
         return buffer;
     }
-    x >>= 10;
-    if (x < 10000)
+    d /= 1024;
+    if (d < 10000)
     {
-        snprintf(buffer, sizeof(buffer), "%4dG", (int)x);
+        format_size_inner(buffer, sizeof(buffer), d, 'G');
         return buffer;
     }
-    x >>= 10;
-    if (x < 10000)
+    d /= 1024;
+    if (d < 10000)
     {
-        snprintf(buffer, sizeof(buffer), "%4dT", (int)x);
+        format_size_inner(buffer, sizeof(buffer), d, 'T');
         return buffer;
     }
-    x >>= 10;
-    if (x < 10000)
+    d /= 1024;
+    if (d < 10000)
     {
-        snprintf(buffer, sizeof(buffer), "%4dP", (int)x);
+        format_size_inner(buffer, sizeof(buffer), d, 'P');
         return buffer;
     }
-    x >>= 10;
-    snprintf(buffer, sizeof(buffer), "%4ldE", (long)x);
+    d /= 1024;
+    format_size_inner(buffer, sizeof(buffer), d, 'E');
     return buffer;
 }
 
@@ -121,7 +138,7 @@ filenamelist_filter_progress::show_start_status(void)
     strcpy(buffer, "\rReading file list: ");
     char *bp = buffer + strlen(buffer);
     snprintf(bp, buffer + sizeof(buffer) - bp, "%s files, ",
-        format_size(list.size()));
+        format_size(items.size()));
     bp += strlen(bp);
     snprintf(bp, buffer + sizeof(buffer) - bp, "%sB ",
         format_size(size_total));
@@ -179,7 +196,7 @@ filenamelist_filter_progress::show_middle_status(void)
         format_size(position));
     bp += strlen(bp);
     snprintf(bp, buffer + sizeof(buffer) - bp, "%s files, ",
-        format_size(list.size()));
+        format_size(items.size()));
     bp += strlen(bp);
 
     snprintf(bp, buffer + sizeof(buffer) - bp, "%sB of ",
@@ -224,7 +241,7 @@ filenamelist_filter_progress::show_end_status(void)
     *bp++ = '\r';
 
     snprintf(bp, buffer + sizeof(buffer) - bp, "%s files, ",
-        format_size(list.size()));
+        format_size(items.size()));
     bp += strlen(bp);
 
     snprintf(bp, buffer + sizeof(buffer) - bp, "%sB, ",
@@ -261,15 +278,15 @@ filenamelist_filter_progress::read_one_line(rcstring &result)
             rcstring temp;
             while (read_one_deeper(temp))
             {
-            show_start_status();
-            struct stat st;
-            if (lstat(temp.c_str(), &st))
-                memset(&st, 0, sizeof(st));
-            long size = S_ISREG(st.st_mode) ? st.st_size : 0;
-            // round up
-            size = ((size + 511) & ~511) + 512;
-            list.push_back(item_t(temp, size));
-            size_total += size;
+                show_start_status();
+                struct stat st;
+                if (lstat(temp.c_str(), &st))
+                    memset(&st, 0, sizeof(st));
+                off_t size = S_ISREG(st.st_mode) ? st.st_size : 0;
+                // round up
+                size = ((size + 511) & ~511) + 512;
+                items.push_back(item_t(temp, size));
+                size_total += size;
             }
             state = state_middle;
             time(&start_time);
@@ -277,10 +294,10 @@ filenamelist_filter_progress::read_one_line(rcstring &result)
         // fall through...
 
     case state_middle:
-        if (position < list.size())
+        if (position < items.size())
         {
             show_middle_status();
-            item_t item = list[position++];
+            item_t item = items[position++];
             result = item.name;
             size_position += item.size;
             return true;
@@ -294,3 +311,40 @@ filenamelist_filter_progress::read_one_line(rcstring &result)
     }
     return false;
 }
+
+
+filenamelist_filter_progress::item_t::~item_t()
+{
+}
+
+
+filenamelist_filter_progress::item_t::item_t(
+    const rcstring &a_name,
+    off_t a_size
+) :
+    name(a_name),
+    size(a_size)
+{
+}
+
+
+filenamelist_filter_progress::item_t::item_t(const item_t &rhs) :
+    name(rhs.name),
+    size(rhs.size)
+{
+}
+
+
+filenamelist_filter_progress::item_t &
+filenamelist_filter_progress::item_t::operator=(const item_t &rhs)
+{
+    if (this != &rhs)
+    {
+        name = rhs.name;
+        size = rhs.size;
+    }
+    return *this;
+}
+
+
+// vim: set ts=8 sw=4 et :
