@@ -1,6 +1,6 @@
 //
 // tardy - a tar post-processor
-// Copyright (C) 2002, 2008, 2009, 2011 Peter Miller
+// Copyright (C) 2002, 2008, 2009, 2011, 2012 Peter Miller
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -76,19 +76,22 @@ private:
 
     struct item_t
     {
-        item_t(const rcstring &arg1, long arg2) :
-            name(arg1), size(arg2)
-        { }
+        ~item_t();
+        item_t(const rcstring &name, off_t size);
+        item_t(const item_t &rhs);
+        item_t &operator=(const item_t &rhs);
 
         rcstring name;
-        long size;
+        off_t size;
     };
 
+    typedef std::deque<item_t> items_t;
+
     /**
-      * The list instance variable is used to keep track of the
+      * The items instance variable is used to keep track of the
       * name and size of each file.
       */
-    std::deque<item_t> list;
+    items_t items;
 
     /**
       * The position instance variable is used to remember where
@@ -113,14 +116,14 @@ private:
       * The size_total instance variable is used to remember the
       * total size of all the files.  This is used to predict the ETA.
       */
-    long long size_total;
+    off_t size_total;
 
     /**
       * The size_position instance variable is used to remember
       * how much data has been transferred so far.  This is used to
       * predict the ETA.
       */
-    long long size_position;
+    off_t size_position;
 
     /**
       * The spinner_state instance variable is used to remember
@@ -139,27 +142,27 @@ private:
       * The spinner method is used to draw the next spinner indicator
       * character.
       */
-    char spinner();
+    char spinner(void);
 
     /**
       * The show_start_status method is used to show how many fiels
       * have been read in to date.
       */
-    void show_start_status();
+    void show_start_status(void);
 
     /**
       * The spinner method is used to show how far along with readin
       * gthe file list we are.  This indirectly indicates how long
       * it will be before we finish (ETA).
       */
-    void show_middle_status();
+    void show_middle_status(void);
 
     /**
       * The show_end_status method is used to shwo the number of
       * files, number of bytes, effective data transfer rate, and
       * elapsed time.
       */
-    void show_end_status();
+    void show_end_status(void);
 
     /**
       * The default constructor.  Do not use.
@@ -178,4 +181,5 @@ private:
         const filenamelist_filter_progress &);
 };
 
+// vim: set ts=8 sw=4 et :
 #endif // LIBTARDY_FILENAMELIST_FILTER_PROGRESS_H
