@@ -1,6 +1,6 @@
 //
 // tardy - a tar post-processor
-// Copyright (C) 2011 Peter Miller
+// Copyright (C) 2011, 2012 Peter Miller
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -17,7 +17,8 @@
 //
 
 #include <libtardy/format_family.h>
-#include <libtardy/rcstring.h>
+#include <libtardy/file/input/gunzip.h>
+#include <libtardy/file/input/bunzip2.h>
 
 
 format_family_t
@@ -25,11 +26,10 @@ format_family_from_filename(const rcstring &filename)
 {
     if (filename.empty() || filename == "standard output")
         return format_family_other;
-    rcstring fn2 = filename.downcase();
-    if (fn2.ends_with(".gz"))
-        fn2 = fn2.substring(0, fn2.size() - 3);
-    // also ".tbz2", etc
-    if (fn2.ends_with(".tgz") || fn2.ends_with(".tar"))
+    rcstring fn2 = filename.basename().downcase();
+    fn2 = file_input_gunzip::remove_filename_suffix(fn2);
+    fn2 = file_input_bunzip2::remove_filename_suffix(fn2);
+    if (fn2.ends_with(".tar"))
         return format_family_tar;
     if (fn2.ends_with(".cpio"))
         return format_family_cpio;
@@ -37,3 +37,4 @@ format_family_from_filename(const rcstring &filename)
         return format_family_ar;
     return format_family_other;
 }
+// vim: set ts=8 sw=4 et :
