@@ -1,6 +1,6 @@
 //
 //      tardy - a tar post-processor
-//      Copyright (C) 1993, 1998, 1999, 2004, 2008, 2009 Peter Miller
+//      Copyright (C) 1993, 1998, 1999, 2004, 2008, 2009, 2011 Peter Miller
 //
 //      This program is free software; you can redistribute it and/or modify
 //      it under the terms of the GNU General Public License as published by
@@ -31,8 +31,10 @@
 //
 #ifdef __GNUC__
 #define ATTR_PRINTF(x, y) __attribute__((__format__(printf, x, y)))
+#define DEPRECATED __attribute__((__deprecated__))
 #else
 #define ATTR_PRINTF(x, y)
+#define DEPRECATED
 #endif
 
 //
