@@ -1,24 +1,24 @@
 //
-//      tardy - a tar post-processor
-//      Copyright (C) 1991-1999, 2001, 2002, 2004, 2008, 2009, 2011 Peter Miller
+// tardy - a tar post-processor
+// Copyright (C) 1991-2001, 2002, 2004, 2008, 2009, 2011, 2012 Peter Miller
 //
-//      This program is free software; you can redistribute it and/or modify
-//      it under the terms of the GNU General Public License as published by
-//      the Free Software Foundation; either version 3 of the License, or
-//      (at your option) any later version.
+// This program is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation; either version 3 of the License, or (at
+// your option) any later version.
 //
-//      This program is distributed in the hope that it will be useful,
-//      but WITHOUT ANY WARRANTY; without even the implied warranty of
-//      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-//      GNU General Public License for more details.
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+// General Public License for more details.
 //
-//      You should have received a copy of the GNU General Public License
-//      along with this program. If not, see
-//      <http://www.gnu.org/licenses/>.
+// You should have received a copy of the GNU General Public License
+// along with this program. If not, see <http://www.gnu.org/licenses/>.
 //
 
 #include <libtardy/ac/assert.h>
 #include <libtardy/ac/errno.h>
+#include <libtardy/ac/stdarg.h>
 #include <libtardy/ac/stdio.h>
 #include <libtardy/ac/stdlib.h>
 #include <libtardy/ac/string.h>
@@ -76,28 +76,6 @@ bigger(void)
 }
 
 
-//
-// NAME
-//      build fake - construct formatting specifier string
-//
-// SYNOPSIS
-//      void build_fake(char *fake, size_t fakesize, int flag, int width,
-//      int prec, int qual, int spec);
-//
-// DESCRIPTION
-//      The build_fake function is used to construct a format
-//      specification string from the arguments presented.  This is
-//      used to guarantee exact replication of printf behaviour.
-//
-// ARGUMENTS
-//      fake    - buffer to store results
-//      flag    - the flag specified (zero if not)
-//      width   - the width specified (zero if not)
-//      prec    - the precision specified (zero if not)
-//      qual    - the qualifier specified (zero if not)
-//      spec    - the formatting specifier specified
-//
-
 static void
 build_fake(char *fake, size_t fakesize, int flag, int width, int precision,
     int qualifier, int specifier)
@@ -121,34 +99,6 @@ build_fake(char *fake, size_t fakesize, int flag, int width, int precision,
 }
 
 
-//
-// NAME
-//      vmprintf_errok - build a formatted string in dynamic memory
-//
-// SYNOPSIS
-//      char *vmprintf_errok(char *fmt, va_list ap);
-//
-// DESCRIPTION
-//      The vmprintf_errok function is used to build a formatted string
-//      in memory.  It understands all of the ANSI standard printf
-//      formatting directives.  Additionally, "%S" may be used to
-//      manipulate (string_ty *) strings.
-//
-// ARGUMENTS
-//      fmt     - string specifying formatting to perform
-//      ap      - arguments of types as indicated by the format string
-//
-// RETURNS
-//      char *; pointer to buffer containing formatted string
-//              NULL if there is an error (sets errno)
-//
-// CAVEATS
-//      The contents of the buffer pointed to will change between calls
-//      to vmprintf_errok.  The buffer itself may move between calls to
-//      vmprintf_errok.  DO NOT hand the result of vmprintf_errok to
-//      free().
-//
-
 char *
 vmprintf_errok(const char *fmt, va_list ap)
 {
@@ -523,46 +473,6 @@ vmprintf_errok(const char *fmt, va_list ap)
                 }
             }
             break;
-
-        case 'S':
-            {
-                string_ty *a = va_arg(ap, string_ty *);
-                size_t len = a->str_length;
-                if (!prec_set)
-                    prec = len;
-                if ((int)len < prec)
-                    prec = len;
-                if (!width_set)
-                    width = prec;
-                if (width < prec)
-                    width = prec;
-                len = width;
-                while (length + len > tmplen)
-                {
-                    if (!bigger())
-                        return 0;
-                }
-                if (flag != '-')
-                {
-                    while (width > prec)
-                    {
-                        tmp[length++] = ' ';
-                        width--;
-                    }
-                }
-                memcpy(tmp + length, a->str_text, prec);
-                length += prec;
-                width -= prec;
-                if (flag == '-')
-                {
-                    while (width > 0)
-                    {
-                        tmp[length++] = ' ';
-                        width--;
-                    }
-                }
-            }
-            break;
         }
     }
 
@@ -580,34 +490,6 @@ vmprintf_errok(const char *fmt, va_list ap)
 }
 
 
-//
-// NAME
-//      mprintf_errok - build a formatted string in dynamic memory
-//
-// SYNOPSIS
-//      char *mprintf_errok(char *fmt, ...);
-//
-// DESCRIPTION
-//      The mprintf_errok function is used to build a formatted string
-//      in memory.  It understands all of the ANSI standard printf
-//      formatting directives.  Additionally, "%S" may be used to
-//      manipulate (string_ty *) strings.
-//
-// ARGUMENTS
-//      fmt     - string spefiifying formatting to perform
-//      ...     - arguments of types as indicated by the format string
-//
-// RETURNS
-//      char *; pointer to buffer containing formatted string
-//              NULL if there is an error (sets errno)
-//
-// CAVEATS
-//      The contents of the buffer pointed to will change between calls
-//      to mprintf_errok.  The buffer itself may move between calls to
-//      mprintf_errok.  DO NOT hand the result of mprintf_errok to
-//      free().
-//
-
 char *
 mprintf_errok(const char *fmt, ...)
 {
@@ -619,33 +501,6 @@ mprintf_errok(const char *fmt, ...)
 }
 
 
-//
-// NAME
-//      vmprintf - build a formatted string in dynamic memory
-//
-// SYNOPSIS
-//      char *vmprintf(char *fmt, va_list ap);
-//
-// DESCRIPTION
-//      The vmprintf function is used to build a formatted string in memory.
-//      It understands all of the ANSI standard printf formatting directives.
-//      Additionally, "%S" may be used to manipulate (string_ty *) strings.
-//
-// ARGUMENTS
-//      fmt     - string spefiifying formatting to perform
-//      ap      - arguments of types as indicated by the format string
-//
-// RETURNS
-//      char *; pointer to buffer containing formatted string
-//
-// CAVEATS
-//      On error, prints a fatal error message and exists; does not return.
-//
-//      The contents of the buffer pointed to will change between calls
-//      to vmprintf.  The buffer itself may move between calls to vmprintf.
-//      DO NOT hand the result of vmprintf to free().
-//
-
 char *
 vmprintf(const char *fmt, va_list ap)
 {
@@ -656,33 +511,6 @@ vmprintf(const char *fmt, va_list ap)
 }
 
 
-//
-// NAME
-//      mprintf - build a formatted string in dynamic memory
-//
-// SYNOPSIS
-//      char *mprintf(char *fmt, ...);
-//
-// DESCRIPTION
-//      The mprintf function is used to build a formatted string in memory.
-//      It understands all of the ANSI standard printf formatting directives.
-//      Additionally, "%S" may be used to manipulate (string_ty *) strings.
-//
-// ARGUMENTS
-//      fmt     - string spefiifying formatting to perform
-//      ...     - arguments of types as indicated by the format string
-//
-// RETURNS
-//      char *; pointer to buffer containing formatted string
-//
-// CAVEATS
-//      On error, prints a fatal error message and exists; does not return.
-//
-//      The contents of the buffer pointed to will change between calls
-//      to mprintf.  The buffer itself may move between calls to mprintf.
-//      DO NOT hand the result of mprintfe to free().
-//
-
 char *
 mprintf(const char *fmt, ...)
 {
@@ -694,36 +522,13 @@ mprintf(const char *fmt, ...)
 }
 
 
-//
-// NAME
-//      vmprintf_str - build a formatted string in dynamic memory
-//
-// SYNOPSIS
-//      char *vmprintf_str(char *fmt, va_list ap);
-//
-// DESCRIPTION
-//      The vmprintf_str function is used to build a formatted string in memory.
-//      It understands all of the ANSI standard printf formatting directives.
-//      Additionally, "%S" may be used to manipulate (string_ty *) strings.
-//
-// ARGUMENTS
-//      fmt     - string spefiifying formatting to perform
-//      ap      - arguments of types as indicated by the format string
-//
-// RETURNS
-//      string_ty *; string containing formatted string
-//
-// CAVEATS
-//      On error, prints a fatal error message and exists; does not return.
-//
-//      It is the resposnsibility of the caller to invoke str_free to release
-//      the results when finished with.
-//
-
-string_ty *
+rcstring
 vmprintf_str(const char *fmt, va_list ap)
 {
     if (!vmprintf_errok(fmt, ap))
         explain_output_error_and_die("mprintf \"%s\"", fmt);
-    return str_n_from_c(tmp, length);
+    return rcstring(tmp, length);
 }
+
+
+// vim: set ts=8 sw=4 et :
