@@ -1,6 +1,6 @@
 //
 // tardy - a tar post-processor
-// Copyright (C) 1994, 1995, 1998, 1999, 2004, 2008, 2009, 2011 Peter Miller
+// Copyright (C) 1994-1998, 1999, 2004, 2008, 2009, 2011, 2012 Peter Miller
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -21,14 +21,15 @@
 
 #include <libtardy/ac/stdarg.h>
 #include <libtardy/main.h>
+#include <libtardy/rcstring.h>
 
 /**
   * The mprintf function is used to format a string into memory.
   *
-  * \param fmt
+  * @param fmt
   *     The mesaage format to use.  See printf(3) for documentation of
   *     the format and its arguments.
-  * \returns
+  * @returns
   *     Pointer to NUL terminated string in synamic memory.
   *     <b>Do not</b> use mem_free when you are done with it.
   */
@@ -38,10 +39,10 @@ char *mprintf(const char *fmt, ...) ATTR_PRINTF(1, 2);
   * The mprintf_errok function is used to format a string into memory.
   * Safe to call from error reporting functions.
   *
-  * \param fmt
+  * @param fmt
   *     The mesaage format to use.  See printf(3) for documentation of
   *     the format and its arguments.
-  * \returns
+  * @returns
   *     Pointer to NUL terminated string in synamic memory.
   *     <b>Do not</b> use mem_free when you are done with it.
   */
@@ -50,12 +51,12 @@ char *mprintf_errok(const char *fmt, ...) ATTR_PRINTF(1, 2);
 /**
   * The mprintf function is used to format a string into memory.
   *
-  * \param fmt
+  * @param fmt
   *     The mesaage format to use.  See vprintf(3) for documentation of
   *     the format and its arguments.
-  * \param arglist
+  * @param arglist
   *     The arguments to be used for the format.
-  * \returns
+  * @returns
   *     Pointer to NUL terminated string in synamic memory.
   *     <b>Do not</b> use mem_free when you are done with it.
   */
@@ -66,12 +67,12 @@ char *vmprintf(const char *fmt, va_list arglist);
   * The mprintf function is used to format a string into memory.
   * Safe to call from error reporting functions.
   *
-  * \param fmt
+  * @param fmt
   *     The mesaage format to use.  See vprintf(3) for documentation of
   *     the format and its arguments.
-  * \param arglist
+  * @param arglist
   *     The arguments to be used for the format.
-  * \returns
+  * @returns
   *     Pointer to NUL terminated string in synamic memory.
   *     <b>Do not</b> use mem_free when you are done with it.
   */
@@ -81,6 +82,7 @@ char *vmprintf_errok(const char *fmt, va_list arglist);
   * The vmprintf_str function is just like the vmprintf function, except
   * that it constructs a string_ty value from it.
   */
-struct string_ty *vmprintf_str(const char *fmt, va_list);
+rcstring vmprintf_str(const char *fmt, va_list);
 
+// vim: set ts=8 sw=4 et :
 #endif // LIBTARDY_MPRINTF_H
