@@ -1,6 +1,6 @@
 //
 // tardy - a tar post-processor
-// Copyright (C) 1991-1999, 2001, 2002, 2008, 2009, 2011 Peter Miller
+// Copyright (C) 1991-1999, 2001, 2002, 2008, 2009, 2011, 2012 Peter Miller
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -42,14 +42,11 @@
 //
 #define MAX_WIDTH 509
 
-static  string_ty       **hash_table;
-static  str_hash_ty     hash_modulus;
-static  str_hash_ty     hash_cutover;
-static  str_hash_ty     hash_cutover_mask;
-static  str_hash_ty     hash_cutover_split_mask;
-static  str_hash_ty     hash_split;
-static  str_hash_ty     hash_load;
-static  int         changed;
+static string_t **hash_table;
+static str_hash_ty hash_modulus;
+static str_hash_ty hash_mask;
+static str_hash_ty hash_load;
+static int changed;
 
 #define MAX_HASH_LEN 20
 
@@ -114,81 +111,65 @@ void
 str_initialize(void)
 {
     hash_modulus = 1<<8; // MUST be a power of 2
-    hash_cutover = hash_modulus;
-    hash_split = hash_modulus - hash_cutover;
-    hash_cutover_mask = hash_cutover - 1;
-    hash_cutover_split_mask = (hash_cutover * 2) - 1;
+    hash_mask = hash_modulus - 1;
     hash_load = 0;
-    hash_table = new string_ty * [hash_modulus];
+    hash_table = new string_t * [hash_modulus];
     for (str_hash_ty j = 0; j < hash_modulus; ++j)
         hash_table[j] = 0;
 }
 
 
-//
-// NAME
-//      split - reduce table loading
-//
-// SYNOPSIS
-//      void split(void);
-//
-// DESCRIPTION
-//      The split function is used to reduce the load factor on the hash table.
-//
-// RETURNS
-//      void
-//
-// CAVEAT
-//      A load factor of about 80% is suggested.
-//
-
+/**
+  * The split function is used to reduce the load factor on the hash table.
+  *
+  * @note
+  *      A load factor of about 80% is suggested.
+  */
 static void
 split(void)
 {
     //
-    // get the list to be split across buckets
+    // double the modulus
     //
-    string_ty *p = hash_table[hash_split];
-    hash_table[hash_split] = 0;
-
+    // This is subtle.  If we only increase the modulus by one, the
+    // load always hovers around 80%, so we have to do a split for
+    // every insert.  I.e. the malloc burden os O(n) for the lifetime of
+    // the program.  BUT if we double the modulus, the length of time
+    // until the next split also doubles, making the probablity of a
+    // split halve, and sigma(2**-n)=1, so the malloc burden becomes O(1)
+    // for the lifetime of the program.
     //
-    // increase the modulus by one order of 2-magnitude
-    // sigma(2**-n) == 1
-    //
-    {
-        size_t new_hash_modulus = hash_modulus * 2;
-        string_ty **new_hash_table = new string_ty * [new_hash_modulus];
-        for (size_t j = 0; j < hash_modulus; ++j)
-            new_hash_table[j] = hash_table[j];
-        for (size_t j = hash_modulus; j < new_hash_modulus; ++j)
-            new_hash_table[j] = 0;
-        delete [] hash_table;
-        hash_table = new_hash_table;
-        hash_modulus = new_hash_modulus;
-    }
-    hash_split = hash_modulus - hash_cutover;
-    if (hash_split >= hash_cutover)
-    {
-        hash_cutover = hash_modulus;
-        hash_split = 0;
-        hash_cutover_mask = hash_cutover - 1;
-        hash_cutover_split_mask = (hash_cutover * 2) - 1;
-    }
+    size_t new_hash_modulus = hash_modulus * 2;
+    string_t **new_hash_table = new string_t * [new_hash_modulus];
+    size_t new_hash_mask = new_hash_modulus - 1;
 
     //
     // now redistribute the list elements
     //
-    while (p)
+    for (size_t idx = 0; idx < hash_modulus; ++idx)
     {
-        string_ty *p2 = p;
-        p = p->str_next;
+        new_hash_table[idx] = 0;
+        new_hash_table[idx + hash_modulus] = 0;
+        string_t *p = hash_table[idx];
+        while (p)
+        {
+            string_t *p2 = p;
+            p = p->str_next;
 
-        str_hash_ty idx = p2->str_hash & hash_cutover_mask;
-        if (idx < hash_split)
-            idx = p2->str_hash & hash_cutover_split_mask;
-        p2->str_next = hash_table[idx];
-        hash_table[idx] = p2;
+            assert((p2->str_hash & hash_mask) == idx);
+            str_hash_ty new_idx = p2->str_hash & new_hash_mask;
+            p2->str_next = new_hash_table[new_idx];
+            new_hash_table[new_idx] = p2;
+        }
     }
+
+    //
+    // replace old hash table with new one
+    //
+    delete [] hash_table;
+    hash_table = new_hash_table;
+    hash_modulus = new_hash_modulus;
+    hash_mask = new_hash_mask;
 }
 
 
@@ -197,21 +178,21 @@ split(void)
 //      str_from_c - make string from C string
 //
 // SYNOPSIS
-//      string_ty *str_from_c(char*);
+//      string_t *str_from_c(char*);
 //
 // DESCRIPTION
 //      The str_from_c function is used to make a string from a null terminated
 //      C string.
 //
 // RETURNS
-//      string_ty* - a pointer to a string in dynamic memory.  Use str_free when
+//      string_t* - a pointer to a string in dynamic memory.  Use str_free when
 //      finished with.
 //
 // CAVEAT
 //      The contents of the structure pointed to MUST NOT be altered.
 //
 
-string_ty *
+string_t *
 str_from_c(const char *s)
 {
     return str_n_from_c(s, strlen(s));
@@ -223,32 +204,29 @@ str_from_c(const char *s)
 //      str_n_from_c - make string
 //
 // SYNOPSIS
-//      string_ty *str_n_from_c(char *s, size_t n);
+//      string_t *str_n_from_c(char *s, size_t n);
 //
 // DESCRIPTION
 //      The str_n_from_c function is used to make a string from an array of
 //      characters.  No null terminator is assumed.
 //
 // RETURNS
-//      string_ty* - a pointer to a string in dynamic memory.  Use str_free when
+//      string_t* - a pointer to a string in dynamic memory.  Use str_free when
 //      finished with.
 //
 // CAVEAT
 //      The contents of the structure pointed to MUST NOT be altered.
 //
 
-string_ty *
+string_t *
 str_n_from_c(const char *s, size_t length)
 {
     if (!hash_table)
         str_initialize();
     str_hash_ty hash = hash_generate(s, length);
 
-    str_hash_ty idx = hash & hash_cutover_mask;
-    if (idx < hash_split)
-        idx = hash & hash_cutover_split_mask;
-
-    for (string_ty *p = hash_table[idx]; p; p = p->str_next)
+    str_hash_ty idx = hash & hash_mask;
+    for (string_t *p = hash_table[idx]; p; p = p->str_next)
     {
         if
         (
@@ -264,8 +242,8 @@ str_n_from_c(const char *s, size_t length)
         }
     }
 
-    string_ty *p =
-        (string_ty *)explain_malloc_or_die(sizeof(string_ty) + length);
+    string_t *p =
+        (string_t *)explain_malloc_or_die(sizeof(string_t) + length);
     p->str_hash = hash;
     p->str_length = length;
     p->str_references = 1;
@@ -275,7 +253,7 @@ str_n_from_c(const char *s, size_t length)
     p->str_text[length] = 0;
 
     hash_load++;
-    while (hash_load * 10 > hash_modulus * 8)
+    if (hash_load * 10 > hash_modulus * 8)
         split();
     ++changed;
     return p;
@@ -287,24 +265,27 @@ str_n_from_c(const char *s, size_t length)
 //      str_copy - make a copy of a string
 //
 // SYNOPSIS
-//      string_ty *str_copy(string_ty *s);
+//      string_t *str_copy(string_t *s);
 //
 // DESCRIPTION
 //      The str_copy function is used to make a copy of a string.
 //
 // RETURNS
-//      string_ty* - a pointer to a string in dynamic memory.  Use str_free when
+//      string_t* - a pointer to a string in dynamic memory.  Use str_free when
 //      finished with.
 //
 // CAVEAT
 //      The contents of the structure pointed to MUST NOT be altered.
 //
 
-string_ty *
-str_copy(string_ty *s)
+string_t *
+str_copy(string_t *s)
 {
-    assert(s->str_references > 0);
-    s->str_references++;
+    if (s)
+    {
+        assert(s->str_references > 0);
+        s->str_references++;
+    }
     return s;
 }
 
@@ -314,7 +295,7 @@ str_copy(string_ty *s)
 //      str_free - release a string
 //
 // SYNOPSIS
-//      void str_free(string_ty *s);
+//      void str_free(string_t *s);
 //
 // DESCRIPTION
 //      The str_free function is used to indicate that a string hash been
@@ -328,7 +309,7 @@ str_copy(string_ty *s)
 //
 
 void
-str_free(string_ty *s)
+str_free(string_t *s)
 {
     if (!s)
         return;
@@ -344,10 +325,8 @@ str_free(string_ty *s)
     // find the hash bucket it was in,
     // and remove it
     //
-    str_hash_ty idx = s->str_hash & hash_cutover_mask;
-    if (idx < hash_split)
-        idx = s->str_hash & hash_cutover_split_mask;
-    for (string_ty **spp = &hash_table[idx]; *spp; spp = &(*spp)->str_next)
+    str_hash_ty idx = s->str_hash & hash_mask;
+    for (string_t **spp = &hash_table[idx]; *spp; spp = &(*spp)->str_next)
     {
         if (*spp == s)
         {
@@ -361,97 +340,18 @@ str_free(string_ty *s)
     //
     // should never reach here!
     //
+#if 1
     explain_output_error_and_die("attempted to free non-existent string (bug)");
-}
-
-
-//
-// NAME
-//      str_catenate - join two strings
-//
-// SYNOPSIS
-//      string_ty *str_catenate(string_ty *, string_ty *);
-//
-// DESCRIPTION
-//      The str_catenate function is used to concatenate two strings to form a
-//      new string.
-//
-// RETURNS
-//      string_ty* - a pointer to a string in dynamic memory.  Use str_free when
-//      finished with.
-//
-// CAVEAT
-//      The contents of the structure pointed to MUST NOT be altered.
-//
-
-string_ty *
-str_catenate( string_ty *s1, string_ty *s2)
-{
-    static char     *tmp;
-    static size_t   tmplen;
-    size_t          length;
-
-    length = s1->str_length + s2->str_length;
-    if (tmplen < length)
-    {
-        delete [] tmp;
-        tmplen = 16;
-        while (tmplen < length)
-            tmplen <<= 1;
-        tmp = new char [tmplen];
-    }
-
-    memcpy(tmp, s1->str_text, s1->str_length);
-    memcpy(tmp + s1->str_length, s2->str_text, s2->str_length);
-    return str_n_from_c(tmp, length);
-}
-
-
-//
-// NAME
-//      str_cat_three - join three strings
-//
-// SYNOPSIS
-//      string_ty *str_cat_three(string_ty *, string_ty *, string_ty *);
-//
-// DESCRIPTION
-//      The str_cat_three function is used to concatenate three strings to form
-//      a new string.
-//
-// RETURNS
-//      string_ty* - a pointer to a string in dynamic memory.  Use str_free when
-//      finished with.
-//
-// CAVEAT
-//      The contents of the structure pointed to MUST NOT be altered.
-//
-
-string_ty *
-str_cat_three(string_ty *s1, string_ty *s2, string_ty *s3)
-{
-    static char     *tmp;
-    static size_t   tmplen;
-    size_t          length;
-
-    length = s1->str_length + s2->str_length + s3->str_length;
-    if (tmplen < length)
-    {
-        delete [] tmp;
-        tmplen = 16;
-        while (tmplen < length)
-            tmplen <<= 1;
-        tmp = new char [tmplen];
-    }
-
-    memcpy(tmp, s1->str_text, s1->str_length);
-    memcpy(tmp + s1->str_length, s2->str_text, s2->str_length);
-    memcpy
+#else
+    explain_output_error
     (
-        tmp + s1->str_length + s2->str_length,
-        s3->str_text,
-        s3->str_length
+        "attempted to free non-existent string %p \"%.*s\" (bug)",
+        s,
+        (int)(s->str_length < 40 ? s->str_length : 40),
+        s->str_text
     );
-    return str_n_from_c(tmp, length);
+    abort();
+#endif
 }
 
 
@@ -460,7 +360,7 @@ str_cat_three(string_ty *s1, string_ty *s2, string_ty *s3)
 //      str_equal - test equality of strings
 //
 // SYNOPSIS
-//      int str_equal(string_ty *, string_ty *);
+//      int str_equal(string_t *, string_t *);
 //
 // DESCRIPTION
 //      The str_equal function is used to test if two strings are equal.
@@ -478,7 +378,7 @@ str_cat_three(string_ty *s1, string_ty *s2, string_ty *s3)
 // this one is inlined in common/str.h
 
 int
-str_equal(string_ty *s1, string_ty *s2)
+str_equal(string_t *s1, string_t *s2)
 {
     return (s1 == s2);
 }
@@ -491,22 +391,22 @@ str_equal(string_ty *s1, string_ty *s2)
 //      str_upcase - upcase a string
 //
 // SYNOPSIS
-//      string_ty *str_upcase(string_ty *);
+//      string_t *str_upcase(string_t *);
 //
 // DESCRIPTION
 //      The str_upcase function is used to form a string which is an upper case
 //      form of the supplied string.
 //
 // RETURNS
-//      string_ty* - a pointer to a string in dynamic memory.  Use str_free when
+//      string_t* - a pointer to a string in dynamic memory.  Use str_free when
 //      finished with.
 //
 // CAVEAT
 //      The contents of the structure pointed to MUST NOT be altered.
 //
 
-string_ty *
-str_upcase(string_ty *s)
+string_t *
+str_upcase(string_t *s)
 {
     static char *tmp;
     static size_t tmplen;
@@ -539,7 +439,7 @@ str_upcase(string_ty *s)
 //      str_bool - get boolean value
 //
 // SYNOPSIS
-//      int str_bool(string_ty *s);
+//      int str_bool(string_t *s);
 //
 // DESCRIPTION
 //      The str_bool function is used to determine the boolean value of the
@@ -552,7 +452,7 @@ str_upcase(string_ty *s)
 //
 
 int
-str_bool(string_ty *s)
+str_bool(string_t *s)
 {
     const char *cp = s->str_text;
     while (*cp)
@@ -570,7 +470,7 @@ str_bool(string_ty *s)
 //      str_field - extract a field from a string
 //
 // SYNOPSIS
-//      string_ty *str_field(string_ty *, char separator, int field_number);
+//      string_t *str_field(string_t *, char separator, int field_number);
 //
 // DESCRIPTION
 //      The str_field functipon is used to erxtract a field from a string.
@@ -582,8 +482,8 @@ str_bool(string_ty *s)
 //      pointer return.  The null string is considered to have one empty field.
 //
 
-string_ty *
-str_field(string_ty *s, int sep, int fldnum)
+string_t *
+str_field(string_t *s, int sep, int fldnum)
 {
     const char *cp = s->str_text;
     while (fldnum > 0)
@@ -627,3 +527,6 @@ operator >= (const rcstring &lhs, const rcstring &rhs)
 {
     return (strcmp(lhs.c_str(), rhs.c_str()) >= 0);
 }
+
+
+// vim: set ts=8 sw=4 et :
