@@ -1,6 +1,6 @@
 //
 // tardy - a tar post-processor
-// Copyright (C) 1991-1999, 2002, 2004, 2008, 2009, 2011 Peter Miller
+// Copyright (C) 1991-1999, 2002, 2004, 2008, 2009, 2011, 2012 Peter Miller
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -25,52 +25,55 @@
 
 typedef unsigned long str_hash_ty;
 
-typedef struct string_ty string_ty;
-struct string_ty
+struct string_t
 {
     str_hash_ty     str_hash;
-    string_ty       *str_next;
+    string_t       *str_next;
     long            str_references;
     size_t          str_length;
     char            str_text[1];
 };
 
 void str_initialize(void);
-string_ty *str_from_c(const char *);
-string_ty *str_n_from_c(const char *, size_t);
-string_ty *str_copy(string_ty *);
-void str_free(string_ty *);
-string_ty *str_catenate(string_ty *, string_ty *);
-string_ty *str_cat_three(string_ty *, string_ty *, string_ty *);
-int str_bool(string_ty *);
+string_t *str_from_c(const char *);
+string_t *str_n_from_c(const char *, size_t);
+string_t *str_copy(string_t *);
+void str_free(string_t *);
+int str_bool(string_t *);
 
 void str_dump(void);
-string_ty *str_field(string_ty *str, int sep, int fldnum);
-string_ty *str_format(const char *, ...) ATTR_PRINTF(1, 2);
-string_ty *str_vformat(const char *, va_list) ATTR_PRINTF(1, 0);
+string_t *str_field(string_t *str, int sep, int fldnum);
 
-bool str_equal(string_ty *s1, string_ty *s2);
+bool str_equal(string_t *s1, string_t *s2);
 
 
 /**
   * The rcstring class is used to represent a reference counted string
-  * class.  It has optinal string equality time charactgerstics.
+  * class.  It has optimal string equality time characterstics.
   */
 class rcstring
 {
 public:
-    ~rcstring() { if (p) str_free(p); }
+    ~rcstring() { str_free(p); p = 0; }
 
     rcstring() : p(0) { }
 
-    rcstring(const rcstring &arg) : p(str_copy(arg.p)) {}
+    rcstring(const rcstring &arg);
 
-    rcstring(const char *arg) : p(str_from_c(arg)) {}
+    rcstring(const char *arg);
 
-    rcstring(const char *arg, size_t len) : p(str_n_from_c(arg, len)) {}
+    rcstring(const char *arg, size_t len);
 
-    rcstring &operator = (const rcstring &arg) { if (p) str_free(p);
-        arg.bind(); p = str_copy(arg.p); return *this; }
+    rcstring &
+    operator=(const rcstring &rhs)
+    {
+        if (this != &rhs)
+        {
+            str_free(p);
+            p = str_copy(rhs.p);
+        }
+        return *this;
+    }
 
     const char *c_str(void) const { return (p ? p->str_text : ""); }
 
@@ -78,15 +81,13 @@ public:
 
     bool empty(void) const { return (!p || p->str_length == 0); }
 
-    str_hash_ty hash(void) const { bind(); return p->str_hash; }
+    str_hash_ty hash(void) const { return (p ? p->str_hash : 0); }
 
-    int operator[] (int n) const { if (n < 0) return 0; bind();
-        if (n >= (int)p->str_length) return 0;
-        return (unsigned char)p->str_text[n]; }
+    int operator[](int n) const;
 
-    rcstring &operator += (const rcstring &arg) { bind(); arg.bind();
-        string_ty *tmp = str_catenate(p, arg.p); str_free(p);
-        p = tmp; return *this; }
+    rcstring operator+(const rcstring &arg) const;
+
+    rcstring &operator+=(const rcstring &arg);
 
     friend bool operator == (const rcstring &, const rcstring &);
     friend bool operator != (const rcstring &, const rcstring &);
@@ -94,7 +95,6 @@ public:
     friend bool operator <= (const rcstring &, const rcstring &);
     friend bool operator > (const rcstring &, const rcstring &);
     friend bool operator >= (const rcstring &, const rcstring &);
-    friend rcstring operator + (const rcstring &, const rcstring &);
 
     /**
       * The downcase method may be used to create a new string, from
@@ -122,7 +122,7 @@ public:
     bool ends_with(const rcstring &suffix) const;
 
     /**
-      * The substring method is used to create a new string by
+      * The substr method is used to create a new string by
       * extracting a substring fron this string.
       *
       * @param begin
@@ -131,7 +131,7 @@ public:
       *     The number of bytes (<b>not</b> characters) to extract.
       *     Will be silently truncated if too long.
       */
-    rcstring substring(size_t begin, size_t nbytes) const;
+    rcstring substr(size_t begin, size_t nbytes) const;
 
     /**
       * The hexdump class method is sued to build a hexadecimal dump
@@ -210,11 +210,17 @@ public:
         size_t how_many_times = -1) const;
 
 private:
-    mutable string_ty *p;
-    void bind(void) const { if (!p) p = str_from_c(""); }
+    string_t *p;
 };
 
 
+inline rcstring
+operator+(const char *lhs, const rcstring &rhs)
+{
+    return (rcstring(lhs) + rhs);
+}
+
+
 inline bool
 operator == (const rcstring &lhs, const char *rhs)
 {
@@ -247,14 +253,5 @@ bool operator <= (const rcstring &, const rcstring &);
 bool operator > (const rcstring &, const rcstring &);
 bool operator >= (const rcstring &, const rcstring &);
 
-inline rcstring
-operator + (const rcstring &lhs, const rcstring &rhs)
-{
-    lhs.bind();
-    rhs.bind();
-    rcstring result;
-    result.p = str_catenate(lhs.p, rhs.p);
-    return result;
-}
-
+// vim: set ts=8 sw=4 et :
 #endif // LIBTARDY_RCSTRING_H
