@@ -1,6 +1,6 @@
 //
 // tardy - a tar post-processor
-// Copyright (C) 2011 Peter Miller
+// Copyright (C) 2011, 2012 Peter Miller
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -20,7 +20,7 @@
 
 
 bool
-str_equal(string_ty *s1, string_ty *s2)
+str_equal(string_t *s1, string_t *s2)
 {
     return (s1 == s2);
 }
@@ -29,16 +29,19 @@ str_equal(string_ty *s1, string_ty *s2)
 bool
 operator == (const rcstring &lhs, const rcstring &rhs)
 {
-    lhs.bind();
-    rhs.bind();
-    return str_equal(lhs.p, rhs.p);
+    string_t *s1 = lhs.p ? lhs.p : str_from_c("");
+    string_t *s2 = rhs.p ? rhs.p : str_from_c("");
+    return str_equal(s1, s2);
 }
 
 
 bool
 operator != (const rcstring &lhs, const rcstring &rhs)
 {
-    lhs.bind();
-    rhs.bind();
-    return !str_equal(lhs.p, rhs.p);
+    string_t *s1 = lhs.p ? lhs.p : str_from_c("");
+    string_t *s2 = rhs.p ? rhs.p : str_from_c("");
+    return !str_equal(s1, s2);
 }
+
+
+// vim: set ts=8 sw=4 et :
