@@ -1,6 +1,6 @@
 //
 // tardy - a tar post-processor
-// Copyright (C) 2011 Peter Miller
+// Copyright (C) 2011, 2012 Peter Miller
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -22,19 +22,8 @@
 void
 rcstring_list::push_back(const rcstring &w)
 {
-    if (nstrings >= nstrings_max)
-    {
-        //
-        // always 8 less than a power of 2, which is
-        // most efficient for many memory allocators
-        //
-        size_t new_nstrings_max = nstrings_max * 2 + 8;
-        rcstring *new_string = new rcstring[new_nstrings_max];
-        for (size_t j = 0; j < nstrings; ++j)
-            new_string[j] = string[j];
-        delete [] string;
-        string = new_string;
-        nstrings_max = new_nstrings_max;
-    }
-    string[nstrings++] = w;
+    contents.push_back(w);
 }
+
+
+// vim: set ts=8 sw=4 et :
