@@ -1,6 +1,6 @@
 //
 // tardy - a tar post-processor
-// Copyright (C) 2011 Peter Miller
+// Copyright (C) 2011, 2012 Peter Miller
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -22,7 +22,8 @@
 void
 rcstring_list::clear(void)
 {
-    for (size_t j = 0; j < nstrings; ++j)
-        string[j].clear();
-    nstrings = 0;
+    contents.clear();
 }
+
+
+// vim: set ts=8 sw=4 et :
