@@ -1,6 +1,6 @@
 //
 // tardy - a tar post-processor
-// Copyright (C) 2011 Peter Miller
+// Copyright (C) 2011, 2012 Peter Miller
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -19,10 +19,10 @@
 #include <libtardy/rcstring/list.h>
 
 
-rcstring_list::rcstring_list(const rcstring_list &from) :
-    nstrings(0),
-    nstrings_max(0),
-    string(0)
+rcstring_list::rcstring_list(const rcstring_list &from)
 {
     push_back(from);
 }
+
+
+// vim: set ts=8 sw=4 et :
