@@ -1,6 +1,6 @@
 //
 // tardy - a tar post-processor
-// Copyright (C) 2011 Peter Miller
+// Copyright (C) 2011, 2012 Peter Miller
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -24,11 +24,18 @@ rcstring_list::intersection(const rcstring_list &rhs)
     const
 {
     rcstring_list result;
-    for (size_t j = 0; j < nstrings; ++j)
+    for
+    (
+        contents_t::const_iterator it = contents.begin();
+        it != contents.end();
+        ++it
+    )
     {
-        const rcstring &s = string[j];
-        if (rhs.member(s))
-            result.push_back_unique(s);
+        if (rhs.member(*it))
+            result.push_back_unique(*it);
     }
     return result;
 }
+
+
+// vim: set ts=8 sw=4 et :
