@@ -1,6 +1,6 @@
 //
 // tardy - a tar post-processor
-// Copyright (C) 2011 Peter Miller
+// Copyright (C) 2011, 2012 Peter Miller
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -16,6 +16,7 @@
 // along with this program. If not, see <http://www.gnu.org/licenses/>.
 //
 
+#include <algorithm>
 #include <libtardy/rcstring/list.h>
 
 
@@ -23,8 +24,8 @@ bool
 rcstring_list::member(const rcstring &w)
     const
 {
-    for (size_t j = 0; j < nstrings; j++)
-        if (string[j] == w)
-            return true;
-    return false;
+    return (contents.end() != std::find(contents.begin(), contents.end(), w));
 }
+
+
+// vim: set ts=8 sw=4 et :
