@@ -1,6 +1,6 @@
 //
 // tardy - a tar post-processor
-// Copyright (C) 2011 Peter Miller
+// Copyright (C) 2011, 2012 Peter Miller
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -25,8 +25,18 @@ bool
 rcstring_list::member_nocase(const rcstring &s)
     const
 {
-    for (size_t j = 0; j < nstrings; j++)
-        if (0 == strcasecmp(string[j].c_str(), s.c_str()))
+    for
+    (
+        contents_t::const_iterator it = contents.begin();
+        it != contents.end();
+        ++it
+    )
+    {
+        if (0 == strcasecmp(it->c_str(), s.c_str()))
             return true;
+    }
     return false;
 }
+
+
+// vim: set ts=8 sw=4 et :
