@@ -1,6 +1,6 @@
 //
 // tardy - a tar post-processor
-// Copyright (C) 2011 Peter Miller
+// Copyright (C) 2011, 2012 Peter Miller
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -22,9 +22,9 @@
 void
 rcstring_list::pop_back(void)
 {
-    if (nstrings)
-    {
-        --nstrings;
-        string[nstrings].clear();
-    }
+    if (!contents.empty())
+        contents.pop_back();
 }
+
+
+// vim: set ts=8 sw=4 et :
