@@ -1,6 +1,6 @@
 //
 // tardy - a tar post-processor
-// Copyright (C) 2011 Peter Miller
+// Copyright (C) 2011, 2012 Peter Miller
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -22,11 +22,19 @@
 void
 rcstring_list::pop_front(void)
 {
-    if (nstrings)
+    if (contents.empty())
+        return;
+    for
+    (
+        contents_t::iterator it = contents.begin() + 1;
+        it != contents.end();
+        ++it
+    )
     {
-        --nstrings;
-        for (size_t j = 0; j < nstrings; ++j)
-            string[j] = string[j + 1];
-        string[nstrings].clear();
+        it[-1] = it[0];
     }
+    pop_back();
 }
+
+
+// vim: set ts=8 sw=4 et :
