@@ -1,6 +1,6 @@
 //
 // tardy - a tar post-processor
-// Copyright (C) 2011 Peter Miller
+// Copyright (C) 2011, 2012 Peter Miller
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -22,25 +22,13 @@
 void
 rcstring_list::push_front(const rcstring &w)
 {
-    if (nstrings >= nstrings_max)
+    contents.push_back(rcstring());
+    for (size_t j = contents.size() - 1; j > 0; --j)
     {
-        //
-        // always 8 less than a power of 2, which is
-        // most efficient for many memory allocators
-        //
-        size_t new_nstrings_max = nstrings_max * 2 + 8;
-        rcstring *new_string = new rcstring[new_nstrings_max];
-        for (size_t j = 0; j < nstrings; ++j)
-            new_string[j + 1] = string[j];
-        delete [] string;
-        string = new_string;
-        nstrings_max = new_nstrings_max;
+        contents[j] = contents[j - 1];
     }
-    else
-    {
-        for (size_t j = nstrings; j > 0; --j)
-            string[j] = string[j - 1];
-    }
-    nstrings++;
-    string[0] = w;
+    contents[0] = w;
 }
+
+
+// vim: set ts=8 sw=4 et :
