@@ -1,6 +1,6 @@
 //
 // tardy - a tar post-processor
-// Copyright (C) 2011 Peter Miller
+// Copyright (C) 2011, 2012 Peter Miller
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -24,7 +24,17 @@ rcstring_list::quote_c(void)
     const
 {
     rcstring_list result;
-    for (size_t j = 0; j < nstrings; ++j)
-        result.push_back(string[j].quote_c());
+    for
+    (
+        contents_t::const_iterator it = contents.begin();
+        it != contents.end();
+        ++it
+    )
+    {
+        result.push_back(it->quote_c());
+    }
     return result;
 }
+
+
+// vim: set ts=8 sw=4 et :
