@@ -1,6 +1,6 @@
 //
 // tardy - a tar post-processor
-// Copyright (C) 2011 Peter Miller
+// Copyright (C) 2011, 2012 Peter Miller
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -22,22 +22,40 @@
 void
 rcstring_list::remove(const rcstring &w)
 {
-    for (size_t j = 0; j < nstrings; ++j)
+    contents_t tmp;
+    contents_t::iterator it = contents.begin();
+    while (it != contents.end())
     {
-        if (string[j] == w)
+        if (*it == w)
         {
-            remove(j);
+            ++it;
             break;
         }
+        tmp.push_back(*it);
+        ++it;
     }
+    while (it != contents.end())
+    {
+        tmp.push_back(*it);
+        ++it;
+    }
+    contents = tmp;
 }
 
 
 void
 rcstring_list::remove(size_t j)
 {
-    nstrings--;
-    for (size_t k = j; k < nstrings; ++k)
-        string[k] = string[k + 1];
-    string[nstrings].clear();
+    if (j >= size())
+        return;
+    contents_t tmp;
+    for (size_t pos = 0; pos < contents.size(); ++pos)
+    {
+        if (j != pos)
+            tmp.push_back(contents[pos]);
+    }
+    contents = tmp;
 }
+
+
+// vim: set ts=8 sw=4 et :
