@@ -1,6 +1,6 @@
 //
 // tardy - a tar post-processor
-// Copyright (C) 2011 Peter Miller
+// Copyright (C) 2011, 2012 Peter Miller
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -16,27 +16,26 @@
 // along with this program. If not, see <http://www.gnu.org/licenses/>.
 //
 
-#include <libtardy/ac/stdlib.h>
-#include <libtardy/ac/string.h>
-
+#include <algorithm>
 #include <libtardy/rcstring/list.h>
 
 
-static int
-cmp(const void *va, const void *vb)
+static bool
+cmp(const rcstring &a, const rcstring &b)
 {
-    const rcstring *a = (const rcstring *)va;
-    const rcstring *b = (const rcstring *)vb;
-    if (a->size() > b->size())
-        return -1;
-    if (a->size() < b->size())
-        return 1;
-    return strcmp(a->c_str(), b->c_str());
+    if (a.size() > b.size())
+        return true;
+    if (a.size() < b.size())
+        return false;
+    return (a < b);
 }
 
 
 void
 rcstring_list::sort_longest_to_shortest(void)
 {
-    qsort(string, nstrings, sizeof(string[0]), cmp);
+    std::sort(contents.begin(), contents.end(), cmp);
 }
+
+
+// vim: set ts=8 sw=4 et :
