@@ -1,6 +1,6 @@
 //
 // tardy - a tar post-processor
-// Copyright (C) 2011 Peter Miller
+// Copyright (C) 2011, 2012 Peter Miller
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -26,12 +26,18 @@ rcstring_list::subset(const rcstring_list &arg)
     //
     // test if "(*this) is a subset of (arg)"
     //
-    if (nstrings > arg.nstrings)
-        return false;
-    for (size_t j = 0; j < nstrings; ++j)
+    for
+    (
+        contents_t::const_iterator it = contents.begin();
+        it != contents.end();
+        ++it
+    )
     {
-        if (!arg.member(string[j]))
+        if (!arg.member(*it))
             return false;
     }
     return true;
 }
+
+
+// vim: set ts=8 sw=4 et :
