@@ -1,6 +1,6 @@
 //
 // tardy - a tar post-processor
-// Copyright (C) 2011 Peter Miller
+// Copyright (C) 2011, 2012 Peter Miller
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -23,14 +23,8 @@ bool
 rcstring_list::validate(void)
     const
 {
-    if (nstrings > nstrings_max)
-        return false;
-    if (nstrings_max && !string)
-        return false;
-#if 0
-    for (size_t j = 0; j < nstrings; ++j)
-        if (!string[j].valid())
-            return false;
-#endif
     return true;
 }
+
+
+// vim: set ts=8 sw=4 et :
