@@ -1,6 +1,6 @@
 //
 // tardy - a tar post-processor
-// Copyright (C) 2011 Peter Miller
+// Copyright (C) 2011, 2012 Peter Miller
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -34,18 +34,26 @@ rcstring
 rcstring_list::unsplit(size_t start, size_t stop, const char *sep)
     const
 {
+    if (start > size())
+        return rcstring();
+    if (stop > size())
+        stop = size();
+
     if (!sep)
         sep = " ";
     size_t seplen = strlen(sep);
 
     static rcstring_accumulator tmp;
     tmp.clear();
-    for (size_t j = start; j <= stop && j < nstrings; j++)
+    for (size_t j = start; j < stop; j++)
     {
-        if (j)
+        if (j != start)
             tmp.push_back(sep, seplen);
-        tmp.push_back(string[j]);
+        tmp.push_back(contents[j]);
     }
 
     return tmp.mkstr();
 }
+
+
+// vim: set ts=8 sw=4 et :
