@@ -1,6 +1,6 @@
 //
 // tardy - a tar post-processor
-// Copyright (C) 2011 Peter Miller
+// Copyright (C) 2011, 2012 Peter Miller
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -16,6 +16,8 @@
 // along with this program. If not, see <http://www.gnu.org/licenses/>.
 //
 
+#include <libtardy/ac/stdarg.h>
+
 #include <libtardy/mprintf.h>
 #include <libtardy/rcstring.h>
 
@@ -33,26 +35,9 @@ rcstring::printf(const char *fmt, ...)
 
 rcstring
 rcstring::vprintf(const char *fmt, va_list ap)
-{
-    rcstring result;
-    result.p = str_vformat(fmt, ap);
-    return result;
-}
-
-
-string_ty *
-str_format(const char *fmt, ...)
-{
-    va_list ap;
-    va_start(ap, fmt);
-    string_ty *result = vmprintf_str(fmt, ap);
-    va_end(ap);
-    return result;
-}
-
-
-string_ty *
-str_vformat(const char *fmt, va_list ap)
 {
     return vmprintf_str(fmt, ap);
 }
+
+
+// vim: set ts=8 sw=4 et :
