@@ -1,6 +1,6 @@
 //
 // tardy - a tar post-processor
-// Copyright (C) 2011 Peter Miller
+// Copyright (C) 2011, 2012 Peter Miller
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -20,7 +20,7 @@
 
 
 rcstring
-rcstring::substring(size_t begin, size_t nbytes)
+rcstring::substr(size_t begin, size_t nbytes)
     const
 {
     if (!p)
@@ -31,3 +31,4 @@ rcstring::substring(size_t begin, size_t nbytes)
         nbytes = p->str_length - begin;
     return rcstring(p->str_text + begin, nbytes);
 }
+// vim: set ts=8 sw=4 et :
