@@ -1,6 +1,6 @@
 //
 // tardy - a tar post-processor
-// Copyright (C) 1991-2009, 2011 Peter Miller
+// Copyright (C) 1991-2009, 2011, 2012 Peter Miller
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -16,10 +16,10 @@
 // with this program. If not, see <http://www.gnu.org/licenses/>.
 //
 
+#include <libtardy/ac/stdarg.h>
+#include <libtardy/ac/stddef.h>
 #include <libtardy/ac/stdio.h>
 #include <libtardy/ac/string.h>
-#include <libtardy/ac/stddef.h>
-#include <libtardy/ac/stdarg.h>
 #include <libexplain/fflush.h>
 #include <libexplain/program_name.h>
 
@@ -29,55 +29,43 @@
 
 #define INDENT 2
 
-typedef struct known_ty known_ty;
-struct known_ty
+struct known_t
 {
-    string_ty       *filename;
-    int         flag;
-    int         *flag_p;
-    known_ty    *next;
+    known_t() :
+        flag(0),
+        flag_p(0),
+        next(0)
+    {
+    }
+
+    rcstring filename;
+    int flag;
+    int *flag_p;
+    known_t *next;
 };
 
-static  string_ty       *file_name;
-static  int         line_number;
-static  int         page_width;
-static  known_ty    *known;
-static  int         depth;
-
-
-static string_ty *
-base_name(const char *file)
-{
-    const char *cp1 = strrchr(file, '/');
-    if (cp1)
-        ++cp1;
-    else
-        cp1 = file;
-    const char *cp2 = strrchr(cp1, '.');
-    if (!cp2)
-        cp2 = cp1 + strlen(cp1);
-    if (cp2 > cp1 + 6)
-        return str_n_from_c(cp1, 6);
-    return str_n_from_c(cp1, cp2 - cp1);
-}
+static rcstring file_name;
+static int line_number;
+static int page_width;
+static known_t *known;
+static int depth;
 
 
 int
 trace_pretest(const char *file, int *result)
 {
-    string_ty *s = base_name(file);
-    known_ty *kp = known;
+    rcstring s = rcstring(file).basename();
+    known_t *kp = known;
     for (; kp; kp = kp->next)
     {
-        if (str_equal(s, kp->filename))
+        if (s == kp->filename)
         {
-            str_free(s);
             break;
         }
     }
     if (!kp)
     {
-        kp = new known_ty;
+        kp = new known_t;
         kp->filename = s;
         kp->next = known;
         kp->flag = 2; // disabled
@@ -92,14 +80,7 @@ trace_pretest(const char *file, int *result)
 void
 trace_where(const char *file, int line)
 {
-    //
-    // take new name fist, because will probably be same as last
-    // thus saving a free and a malloc (which are slow)
-    //
-    string_ty *s = base_name(file);
-    if (file_name)
-        str_free(file_name);
-    file_name = s;
+    file_name = rcstring(file).basename();
     line_number = line;
 }
 
@@ -107,10 +88,10 @@ trace_where(const char *file, int line)
 static void
 trace_putchar(int c)
 {
-    static char     buffer[200];
-    static char     *cp;
-    static int      in_col;
-    static int      out_col;
+    static char buffer[200];
+    static char *cp;
+    static int in_col;
+    static int out_col;
 
     if (!page_width)
     {
@@ -129,8 +110,8 @@ trace_putchar(int c)
         cp = buffer + 6;
         *cp++ = ':';
         *cp++ = '\t';
-        strcpy(cp, file_name->str_text);
-        cp += file_name->str_length;
+        strcpy(cp, file_name.c_str());
+        cp += file_name.size();
         *cp++ = ':';
         *cp++ = '\t';
         snprintf(cp, buffer + sizeof(buffer) - cp, "%d:\t", line_number);
@@ -217,23 +198,19 @@ trace_printf(const char *s, ...)
 void
 trace_enable(const char *file)
 {
-    string_ty       *s;
-    known_ty    *kp;
-
-    s = base_name(file);
+    rcstring s = rcstring(file).basename();
+    known_t *kp;
     for (kp = known; kp; kp = kp->next)
     {
-        if (str_equal(s, kp->filename))
+        if (s == kp->filename)
         {
-            str_free(s);
             break;
         }
     }
     if (!kp)
     {
-        kp = new known_ty;
+        kp = new known_t;
         kp->filename = s;
-        kp->flag_p = 0;
         kp->next = known;
         known = kp;
     }
