@@ -10,9 +10,9 @@
 "case is not important.",
 ".PP",
 "For example:",
-"the arguments \"-help, \"-HELP\" and \"-h\" are",
-"all interpreted to mean the \\fB-Help\\fP option.",
-"The argument \"-hlp\" will not be understood,",
+"the arguments \\[lq]\\-help\\[rq], \\[lq]\\-HELP\\[rq] and \\[lq]\\-h\\[rq] are",
+"all interpreted to mean the \\fB\\-Help\\fP option.",
+"The argument \\[lq]-hlp\\[rq] will not be understood,",
 "because consecutive optional characters were not supplied.",
 ".PP",
 "Options and other command line arguments may be",
