@@ -1,5 +1,5 @@
 ".TP 8n",
-".B -Help",
+".B \\-Help",
 ".br",
 "This option may be used to obtain more information about how to use the",
 ".I \\*(n)",
