@@ -10,10 +10,10 @@
 ".br",
 ".PP",
 "The \\*(n) program comes with ABSOLUTELY NO WARRANTY;",
-"for details use the '\\fI\\*(n) -VERSion License\\fP' command.",
+"for details use the \\[lq]\\fI\\*(n)\\-VERSion License\\fP\\[rq] command.",
 "This is free software",
 "and you are welcome to redistribute it under certain conditions;",
-"for details use the '\\fI\\*(n) -VERSion License\\fP' command.",
+"for details use the \\[lq]\\fI\\*(n)\\-VERSion License\\fP\\[rq] command.",
 ".br",
 ".ne 1i",
 ".SH AUTHOR",
@@ -21,5 +21,5 @@
 "tab(;);",
 "l r l.",
 "Peter Miller;EMail:;pmiller@opensource.org.au",
-"\\f(CW/\\e/\\e*\\fR;WWW:;http://miller.emu.id.au/pmiller/",
+"\\f[CW]/\\e/\\e*\\f[R];WWW:;http://miller.emu.id.au/pmiller/",
 ".TE",
