@@ -1,6 +1,6 @@
 //
 // tardy - a tar post-processor
-// Copyright (C) 1993-1996, 1998, 1999, 2001-2004, 2008, 2009, 2011 Peter Miller
+// Copyright (C) 1993-1999, 2001-2004, 2008, 2009, 2011, 2012 Peter Miller
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -23,8 +23,10 @@
 
 #include <libtardy/file/input.h>
 #include <libtardy/file/output/buffer.h>
+#include <libtardy/file/output/bzip2.h>
 #include <libtardy/file/output/gzip.h>
 #include <libtardy/file/output/hexdump.h>
+#include <libtardy/file/output/xz.h>
 #include <tardy/ifmt.h>
 #include <tardy/ofmt.h>
 #include <libtardy/tar/input/filter/clean.h>
@@ -264,8 +266,9 @@ tardy(const char *ifn, const char *ofn)
     if (hexdump)
         ofpx = file_output_hexdump::create(ofpx);
     ofpx = file_output_buffer::create(ofpx, blocksize);
-    if (ofpx->filename_implies_gzip())
-        ofpx = file_output_gzip::create(ofpx);
+    ofpx = file_output_gzip::create_if_candidate(ofpx);
+    ofpx = file_output_bzip2::create_if_candidate(ofpx);
+    ofpx = file_output_xz::create_if_candidate(ofpx);
     tar_output::pointer ofp;
     if (extract)
     {
@@ -626,3 +629,6 @@ tardy_relative_paths(void)
         explain_output_error_and_die("duplicate -RELative-paths option");
     relative_paths = true;
 }
+
+
+// vim: set ts=8 sw=4 et :
