@@ -19,6 +19,7 @@
 #ifndef TARDY_TARDY_H
 #define TARDY_TARDY_H
 
+#include <libtardy/ac/time.h>
 #include <libtardy/main.h>
 
 void tardy_clean_meta(void);
@@ -38,7 +39,7 @@ void tardy_mode_set(int);
 void tardy_no_directories(void);
 void tardy_no_fix_type(void);
 void tardy_now(void);
-void tardy_mtime(long when);
+void tardy_mtime(time_t when);
 void tardy_prefix(const char *);
 void tardy_remove_prefix(const char *);
 void tardy_remove_prefix(long);
